@@ -10,8 +10,7 @@ use proc_macro2::{Ident, Span};
 use quote::{quote, ToTokens};
 use syn::{AttributeArgs, Expr, ItemFn, ItemMod, ItemStruct, Path};
 use url::Url;
-use xml::EventReader;
-use xml::reader::XmlEvent;
+
 
 use crate::html_loader::{Element, load_html};
 use crate::proc_macro::TokenStream;
@@ -530,6 +529,7 @@ fn impl_if(test_value: &str, if_tag_body: proc_macro2::TokenStream, body: &mut p
     *body = quote! {
                   #body
                   if #method_name {
+                     sql.push_str(" ");
                      #if_tag_body
                      #appends
                   }
